"""Saku Configuration.
"""
#
# Copyright (c) 2005,2006 shinGETsu Project.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#
# $Id: config.py 1220 2006-07-12 12:27:43Z fuktommy $
#

import re
import os.path
import ConfigParser

__version__ = "$Revision: 1220 $"

def _get_value(parser, section, key, default, vtype=''):
    """Get config value or default value."""
    try:
        if vtype == 'int':
            return parser.getint(section, key)
        elif vtype == 'path':
            return os.path.expanduser(parser.get(section, key))
        elif vtype == 'boolean':
            return parser.getboolean(section, key)
        else:
            return parser.get(section, key)
    except (ConfigParser.NoOptionError, ConfigParser.NoSectionError):
        return default

# External config files.
_extconf = ConfigParser.SafeConfigParser()
_extconf.read(['file/saku.ini',
               '/usr/local/etc/saku/saku.ini',
               '/etc/saku/saku.ini',
               os.path.expanduser('~/.saku/saku.ini')])

# Application types
types = ("thread",)

port = _get_value(_extconf, 'Network', 'port', 8000, 'int')
use_upnp = _get_value(_extconf, 'Network', 'upnp', False, 'boolean')

docroot = _get_value(_extconf, 'Path', 'docroot', './www', 'path')
log_dir = _get_value(_extconf, 'Path', 'log_dir', './log', 'path')
run_dir = _get_value(_extconf, 'Path', 'run_dir', '../run', 'path')
file_dir = _get_value(_extconf, 'Path', 'file_dir', '../file', 'path')
cache_dir = _get_value(_extconf, 'Path', 'cache_dir', '../cache', 'path')
spam_list = _get_value(_extconf, 'Path', 'spam_list',
                       '../file/spam.txt', 'path')

admin = _get_value(_extconf, 'Gateway', 'admin', r'^127')
friend = _get_value(_extconf, 'Gateway', 'friend', r'^127')
visitor = _get_value(_extconf, 'Gateway', 'visitor', r'.')
rss_range = _get_value(_extconf, 'Gateway', 'rss_range', 3*24*60*60, 'int')
re_admin = re.compile(admin)
re_friend = re.compile(friend)
re_visitor = re.compile(visitor)

tklog = _get_value(_extconf, 'Interface', 'tklog', 100, 'int')

# Seconds; 0 for infinity
save_record = {}
get_range = {}
sync_range = {}
save_removed = {}
for type in types:
    ctype = 'Application %s' % type.capitalize()
    save_record[type] = \
        _get_value(_extconf, ctype, 'save_record', 31*24*60*60, 'int')
    get_range[type] = \
        _get_value(_extconf, ctype, 'get_range', 31*24*60*60, 'int')
    sync_range[type] = \
        _get_value(_extconf, ctype, 'sync_range', 10*24*60*60, 'int')
    save_removed[type] = \
        _get_value(_extconf, ctype, ' save_removed', 50*24*60*60, 'int')

client_cycle = 5*60         # Seconds; Access client.cgi
ping_cycle = 5*60           # Seconds; Check nodes
sync_cycle = 5*60*60        # Seconds; Check cache
init_cycle = 20*60          # Seconds; Check initial node
upnp_cycle = 1*60*60        # Seconds
update_range = 24*60*60     # Seconds
recent_range = 3*24*60*60   # Seconds
wait_update = 10            # Seconds
time_error = 60             # Seconds
search_timeout = 10*60      # Seconds
timeout = 20                # Seconds; Timeout for TCP
get_timeout = 2*60          # Seconds; Timeout for /get
client_timeout = 30*60      # Seconds; client_timeout < sync_cycle
upnp_timeout = 20           # Seconds
tk_save_warn = 5*60         # Seconds
retry = 5                   # Times; Common setting
nodes = 5                   # Nodes keeping in node list
share_nodes = 5             # Nodes having the file
search_depth = 30           # Search node size
file_limit = 10             # MegaBytes; File size limit

broadcast = "../tool/broadcast.py"  # Broadcast script path

rss = "1"                                   # 1/2; RSS version
google = "http://www.google.co.jp/search"
language = "en"                             # Language code (see RFC3066)

# regexp
robot = r"Google|bot|Yahoo|archiver|Wget|Crawler"

dnsname = ""                            # Server name
query_separator = "/"                   # Charactor for foo.cgi[/?]bar
root_path = "/"                         # path of URI for root
indexes = ['index.html', 'index.htm']   # index of top (replace gateway.cgi)

motd = file_dir + "/motd.txt"
node = run_dir + "/node.txt"
search = run_dir + "/search.txt"
update = run_dir + "/update.txt"
recent = run_dir + "/recent.txt"
client_log = run_dir + "/client.txt"
lock = run_dir + "/lock.txt"
search_lock = run_dir + "/touch.txt"
admin_search = run_dir + "/admintouch.txt"
admin_sid = run_dir + "/sid.txt"

server = root_path + "server.cgi"
client = root_path + "client.cgi"
gateway = root_path + "gateway.cgi"
thread_cgi = root_path + "thread.cgi"
admin_cgi = root_path + "admin.cgi"
xsl = root_path + "rss1.xsl"

application = {"thread": thread_cgi}

use_cookie = True
save_cookie = 7*24*60*60                # Seconds
title_limit = 30                        # Charactors

version = "shinGETsu/0.6 (Saku/1.5.3)"

init_node = ["node.shingetsu.info:8000/server.cgi",
             "fuktommy.ddo.jp:8000/server.cgi",
             "feeling.zive.net:8000/server.cgi",
             "pushare.zenno.info:8000/server.cgi"]

ignore_search_node = []

flags = []          # It is set by script
